# Ansible Collection - oraclelinux.private_automation_hub

## Build Collection

```sh
ansible-galaxy collection build
```
- Will generate the collection tar ball


## Single-Node Setup

#### Create Hosts Inventory File
Example inventory file (hosts.singlenode.example):
```sh
all:
  hosts:
    hub:
      ansible_host: TARGET_HOST_DNSNAME_OR_IP
      ansible_user: TARGET_HOST_USER
```
- Replace hosts `TARGET_HOST_DNSNAME_OR_IP` with your target hostname or IP
- Replace hosts `TARGET_HOST_USER` with your target host user. (default user for OCI is `opc`)


#### Set Passwords & Run playbook
- olpah_admin_password is the `Hub` admin password
- olpah_db_password is the `Database` password for `pulp` user
```sh
ansible-playbook single-node-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password"
```
- With added configurations in single-node-vars.yml (ex: LDAP, connected_olam_controllers, olpah_require_content_approval), use this command with the mention of vars file:
```sh
ansible-playbook single-node-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password" -e "@single-node-vars.yml"
```

#### See Result
Login at https://<target_host_ip_or_fqdn>




## LDAP Integration

#### Add Configuration into vars.yml file
- For example, in playbooks/single-node/single-node-vars.yml or playbooks/cluster/cluster-vars.yml:
```sh
#Enable galaxy_ng LDAP Integration
config_ldap: True

# LDAP Binding and Directory Look Up
auth_ldap_server_uri: "ldap://<LDAP_SERVER_URL>"
auth_ldap_bind_dn: "<LDAP_BINGING>"
auth_ldap_bind_password: "<LDAP_BIND_PASSWORD>"
auth_ldap_user_search_base_dn: "<LDAP_USER_SEARCH_BASE_DN>"
auth_ldap_user_search_scope: "<LDAP_USER_SEARCHSCOPE>"
auth_ldap_user_search_filter: "<LDAP_USER_SEARCH_FILTER>"
auth_ldap_group_search_base_dn: "<LDAP_GROUP_SEARCH_BASE_DN>"
auth_ldap_group_search_scope: "<LDAP_GROUP_SEARCH_SCOPE>"
auth_ldap_group_search_filter: "<LDAP_GROUP_SEARCH_FILTER>"
auth_ldap_group_type_class: "<LDAP_GROUP_TYPE_CLASS>"
auth_ldap_user_flags_by_group__is_superuser: "<LDAP_USER_FLAGS_BY_GROUP_IS_SUPERUSER>"

# LDAP Backend
ldap_logging: True
auth_ldap_start_tls: True
use_galaxy_ldap_self_signed_cert: True
auth_ldap_mirror_groups: True
```

#### Run Playbook (Single-Node)
```sh
ansible-playbook single-node-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password" -e "@single-node-vars.yml"
```






## Connect OLAM Controllers

#### Define connected_olam_controllers in xxx-vars.yml file
- The "http://" prefix is required for the web link to work
- Define the var as a list.
```sh
connected_olam_controllers: [
  "https://<OLAM_CONTROLLER_URL>/"
]
```


#### Run Playbook (Single-Node)
```sh
ansible-playbook single-node-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password" -e "@single-node-vars.yml"
```






## Existing Remote Database

#### Create DB Schema and User
- Create db user `pulp` on existing database server
```sh
sudo su - postgres -c "createuser -S -P pulp"
```
- Create db schema `pulp` on existing database server
```sh
sudo su - postgres -c "createdb -O pulp pulp"
```
- Utilize the `--extra-vars`/`-e` argument in the command line by replacing `EXISTING_DB_HOST_DNSNAME_OR_IP` with your existing db hostname or IP
```sh
-e "existing_db_host=EXISTING_DB_HOST_DNSNAME_OR_IP"
```
- Or add configuration in vars file:
```sh
existing_db_host: <EXISTING_DB_HOST_DNSNAME_OR_IP>
```

#### Remove pulp_database role
- With the removal of pulp_database role, playbook won't install a redundant Postgres server on the target host.
- For example, in the original single-node-install.yml:
```sh
  roles:
    - olpah_preconfig
    - pulp_database
    - pulp_redis
    - pulp_services
    - pulp_health_check
    - pulp_webserver
    - olpah_postconfig
    - olpah_pulp_ldap
    - olpah_restart
```
-  After removing pulp_database role:
```sh
  roles:
    - olpah_preconfig
    - pulp_redis
    - pulp_services
    - pulp_health_check
    - pulp_webserver
    - olpah_postconfig
    - olpah_pulp_ldap
    - olpah_restart
```

#### Run Playbook (Single-Node)
```sh
ansible-playbook single-node-install.yml -i hosts -e "existing_db_host=EXISTING_DB_HOST_DNSNAME_OR_IP"
```
- If choose to add configuration in vars file:
```sh
ansible-playbook single-node-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password" -e "@single-node-vars.yml"
```



## HA Setup

#### Switch to cluster playbook directory
```sh
cd /usr/share/ansible/collections/ansible_collections/oraclelinux/private_automation_hub/playbooks/cluster
```

#### Create Inventory File
##### Topology
- Pulp Server 1, a.k.a `<ps1>`
- Pulp Server 2, a.k.a `<ps2>`
- NFS Server, a.k.a `<nfsserver>`
- Redis + Postgresql Server, a.k.a `<redispgserver>`
- Default username for OCI is `opc`
- Example inventory file (hosts.ha.example):
```sh
hubservers:
  hosts:
    node1:
      ansible_host: <ps1>
      ansible_user: TARGET_HOST_USER
    node2:
      ansible_host: <ps2>
      ansible_user: TARGET_HOST_USER

redispgservers:
  hosts:
    redispg1:
      ansible_host: <redispgserver>
      ansible_user: TARGET_HOST_USER

nfsservers:
  hosts:
    nfs1:
      ansible_host: <nfsserver>
      ansible_user: TARGET_HOST_USER
      
all:
  children:
    hubservers:
    redispgservers:
    nfsservers:
```

- Replace hosts `<ps1>`, `<ps2>`, `<redispgserver>`, `<nfsserver>` with your HA setup hostnames or ips
- Replace hosts `TARGET_HOST_USER` with your target host user. (default user for OCI is `opc`)

#### Set Passwords & Run playbook
- olpah_admin_password is the `Hub` admin password
- olpah_db_password is the `Database` password for `pulp` user
- ✨Make Sure all hosts are under the same CIDR block. Ex: VNIC `All-Regional-iad.sub`'s CIDR block is `100.100.248.0/21`. 

##### Option 1
- You can customize this setting by utilizing the `--extra-vars`/`-e` argument in the command line:
```sh
-e "nfs_ipv4_cidr_block=YOUR_NETWORK_IPV4_CIDR_BLOCK"
```
- Then run the playbook:
```sh
ansible-playbook cluster-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password nfs_ipv4_cidr_block=<YOUR_NETWORK_IPV4_CIDR_BLOCK>"
```

##### Option 2
- Edit variable `nfs_ipv4_cidr_block` in cluster-vars.yml
```sh
#NFS Settings
nfs_ipv4_cidr_block: "<YOUR_NETWORK_IPV4_CIDR_BLOCK>"
```
- Then run the playbook as usual:
```sh
ansible-playbook cluster-install.yml -i hosts -e "olpah_admin_password=password olpah_db_password=password" -e "@cluster-vars.yml"
```

#### See Result
Login at https://`<ps1 ip or fqdn>` or https://`<ps2 ip or fqdn>`










## Testing

- Add below in single-node-vars.yml to configure test repo:

#### Test Against Stage Repo
```
# Yum Repo setting
__pulp_pkg_repo_name: "ol_automation2"
pulp_pkg_repo: "http://100.99.32.182/galaxy_ng/RPMS/"
pulp_pkg_repo_gpgcheck: 0
__pulp_pkg_repo_gpgkey: "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-oracle"
```

#### Test Against yum-qa
```
# Yum Repo setting
__pulp_pkg_repo_name: "ol_automation2"
pulp_pkg_repo: "https://yum-qa.$ocidomain/repo/OracleLinux/OL8/automation2/basearch/"
pulp_pkg_repo_gpgcheck: 0
__pulp_pkg_repo_gpgkey: "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-oracle"
```


## A List of OLPAH Configurable vars
```sh
# Password
olpah_admin_password: password
olpah_db_password: password

# DB
existing_db_host: EXISTING_DB_HOST_DNSNAME_OR_IP

# pulp_settings flattener
olpah_secret_key: secret
olpah_content_origin: "https://{{ ansible_fqdn }}"
olpah_api_host: 127.0.0.1
olpah_api_port: 24817
olpah_api_user: "admin"
olpah_api_prefix: "pulp_ansible/galaxy/automation-hub/api"
olpah_require_content_approval: False
olpah_tokenserver_auth_disabled: True
olpah_api_default_distribution_base_path: "published"
olpah_db_name: pulp
olpah_db_user: pulp

# pulp_settings flattener (clustering)
olpah_cluster_redis_host: "{{ hostvars['redispg1']['ansible_host'] }}"

# Performance
pulp_api_workers: 2

# Upgrade
pulp_pkg_upgrade_all: True

# Yum Repo setting
__pulp_pkg_repo_name: "ol_automation2"
pulp_pkg_repo: "https://yum-qa.$ocidomain/repo/OracleLinux/OL8/automation2/basearch/"
pulp_pkg_repo_gpgcheck: 0
__pulp_pkg_repo_gpgkey: "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-oracle"
```
